=begin

Name : SetArcCircleDefaults

	Description : When SketchUp loads, this script selects the circle tool and changes the number of sides to the circle (to predifined user preference), then selects the arc tool and changes the segments in the arc (also to user preference).  This way it effectively sets their "defaults" (to lower or higher numbers) according to user preference.  As this script comes "shipped", it sets the sides of a circle to 12, and the segments in an arc to 6.

	(The defaults for sides of a circle and segments in an arc could be directly set via SketchUp's Ruby API.. if it let you do that.  It doesn't as of SU V8.)

	This script requires the eventrelay plugin (windows	only at this writing), or EventRelay.dll, and includes a version of that .dll known at this writing to work.  eventrelay is available at http://code.google.com/p/eventrelay/

	Author : Alex Hall (c) 2011 http://blog.openhatch.net/contact/
		Released under the GNU GPL v2

	Installation: At this writing, and unless eventrelay is ported to the Macintosh, this plugin is for Windowls only.  Copy these files into the Sketchup Plugins directory:

		EventRelay.dll
		SetArcCircleDefaults.rb
		setArcCircleDefaults-config.txt

	(For example, Google Sketchup 8's plugin directory on Windows 7 defaults to: "C:\Program Files (x86)\Google\Google SketchUp 8\Plugins" - copy these files there in that case.  For help finding the plugin directory look in the forums: http://forums.sketchucation.com/search.php?keywords=plugin+folder+OR+directory)

	Usage : To alter the "defaults" which the script sets for sides of a circle and segments of an arc, go to the "Plugins->Set Circle and Arc Segments Defaults", enter the desired values in the popup box, and click "OK".

	POSSIBLE CAVEAT: If you select any window besides SketchUp while SketchUp is loading, it may type key-presses to change these settings into some document or web browser text box etc. It [i]seems[/i] the script avoids that by typing an inert {TAB} key, but if your set "defaults" for the Circle and Arc tool don't load with SketchUp, make sure you don't select any other windows after starting SketchUp to load.

	You could also modify the script to exploit any of the functionality of the eventrelay plugin.

	For defaults, numbers divisible by four may be advisable, as they will provide vertices at right angles along the perimiter of the circle, which makes for easy rotation and geometric snapping/angular construction.

	Future plans: possible exception handling for any errors related to config file.

	Version history:

	[UPDATE] 1.1 Revamped from scratch, incorporating suggestions by AlexMozg.  Added config storage to setArcCircleDefaults-config.txt file in plugin directory (with setting via "Plugins->Set Circle and Arc Segments Defaults" menu.)

	1.0 08/11 Planned updates : none.  Could have menu option to alter and store "defaults"; not programming that.  Anyone else is free to.

--------------------------------------------------------------------------------
=end


require 'sketchup.rb'
require "EventRelay.dll"

def setArcCircleDefaults(prompt)

pluginsDir = Sketchup.find_support_file("Plugins")
configFile = pluginsDir + "/setArcCircleDefaults-config.txt"
lines = IO.read(configFile)
	#Exceptions for nonexistent config file needed here!
circleSides, arcSegments = lines.split("\n")
	#Exceptions for bad variables from config file needed here.

	if prompt == true
		prompts = ["Sides to a Circle:", "Segments in an Arc:"]
		defaults = [circleSides, arcSegments]
		input = UI.inputbox prompts, defaults, "Defaults for Circle and Arc tools"
		circleSides = input[0]
		arcSegments = input[1]
		outFile = File.open(configFile, "w")
		outFile.puts circleSides
		outFile.puts arcSegments
		outFile.close
		prompt = false
	end

myEventRelay = EventRelay.new

# Thanks to AlexMozg via forums.sketchucation.com for this structure
# (in testing, the timer code makes it work where it *doesn't* without?!)
# and suggestion to use send_action instead of key macros (as key shortcuts can change)

	UI.start_timer(0, false){
	Sketchup.send_action   "selectSelectionTool:"
	myEventRelay.SendKeyMacro("{TAB}")
		UI.start_timer(0, false){
			Sketchup.send_action   "selectCircleTool:"
			myEventRelay.SendKeyMacro(circleSides.to_s + "s{ENTER}")
			UI.start_timer(0, false){
				Sketchup.send_action   "selectArcTool:"
				UI.start_timer(0, false){
				myEventRelay.SendKeyMacro(arcSegments.to_s + "s{ENTER}")
					UI.start_timer(0, false){Sketchup.send_action   "selectSelectionTool:"}
				}
			}
		}
	}
end

unless file_loaded?("setArcCircleDefaults.rb")

setArcCircleDefaults(false)

UI.menu("Plugins").add_item("Set Circle and Arc Segments Defaults") {setArcCircleDefaults(true)}

file_loaded "setArcCircleDefaults.rb"
end